  function     [deharm_result]=deharm(data,period)                                                                 
%    Program DEHARM - removes user-specified harmonic components
%     from a time series. (no uniform sampling needed)
%
%	Need inputs:
%	   data=2-D array with (t,y)
%	   period = period to estimate and remove
%  	output:
%	   y=1-D vector with detrended, deharmonized y variable
%	   t=1-D vector with time variable
%	   curve=1-D vector with fitted sinusoid   
% This function is provided by Linda Hinnov to Mingsong Li for personal use
s=[ ];
c=[ ];
curve=[ ];
t=data(:,1);                                      % time or depth of data
y=data(:,2);                                      % value
%figure;plot(t,y);                                 % figure
y=detrend(y);                                     % 
npts=length(y);                                   % number of data points
freq=1.0/period;                                  % calculate frequency                               
deharm_result=[];                                 % Add by M.Li Nov16, 2014
fitcurve=[];                                      % Add by M.Li Nov16, 2014
%%
for n=1:npts                                      % circulation for calculate each                                   
   tt=t(n);                                            
   c(n)=cos(2.0*pi*tt*freq);                      % normal cosine wave                           
   s(n)=sin(2.0 *pi*tt*freq);                     % normal sine wave               
end                                                          
X1=0.0;                                                        
X2=0.0;                                                       
X3=0.0;                                                        
X4=0.0;                                                        
X5=0.0;                                                       
X6=0.0;                                                        
for n=1:npts                                                  
  X1 = X1 + y(n)*c(n);                                             
  X2 = X2 + c(n)*c(n);                                             
  X3 = X3 + y(n)*s(n);                                             
  X4 = X4 + c(n)*s(n);                                             
  X5 = X5 + s(n)*c(n);                                             
  X6 = X6 + s(n)*s(n);                                             
end                                                          
B=(X1*X4-X2*X3)/(X4*X5-X2*X6);                             
A=(X1-B*X5)/X2;                                              

% for n=1:npts                                 % calculate a fit curve using given period                                   
%   curve(n)=A*c(n)+B*s(n);                                       
%   y(n)=y(n) - curve(n);                                               
% end
%% plot and output
amp=sqrt(A*A+B*B);                           % Add by M.Li Nov16,2014
phase=atan2(A,B);                            % Add by M.Li Nov16,2014
%disp('   period     freq      amp        phase        A       B');
deharm_result=[period,amp,phase];    % Add by M.Li Nov16,2014
% fitcurve=[t,curve'];
%figure;plot(t,curve);                        % 
%figure;plot(t,y);                            %                                   
end
